@@ -13,10 +13,11 @@ from matplotlib.lines import Line2D
 import pandas as pd
 
 
-from tempowork.CIG import cig_network as cig
-from tempowork.IT_nil import nil
-from tempowork.IT_node import IT_node
-from tempowork.IT import Interval_Tree
+
+from tw.CIG import cig_network as cig
+from tw.IT_nil import nil
+from tw.IT_node import IT_node
+from tw.IT import Interval_Tree
 
 
 
